package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.InfoAddress;

/**
 * addressService接口
 * 
 * @author ruoyi
 * @date 2023-05-24
 */
public interface IInfoAddressService extends IService<InfoAddress>
{
    /**
     * 查询address
     * 
     * @param id address主键
     * @return address
     */
    public InfoAddress selectInfoAddressById(Long id);

    /**
     * 查询address列表
     * 
     * @param infoAddress address
     * @return address集合
     */
    public List<InfoAddress> selectInfoAddressList(InfoAddress infoAddress);

    /**
     * 新增address
     * 
     * @param infoAddress address
     * @return 结果
     */
    public int insertInfoAddress(InfoAddress infoAddress);

    /**
     * 修改address
     * 
     * @param infoAddress address
     * @return 结果
     */
    public int updateInfoAddress(InfoAddress infoAddress);

    /**
     * 批量删除address
     * 
     * @param ids 需要删除的address主键集合
     * @return 结果
     */
    public int deleteInfoAddressByIds(Long[] ids);

    /**
     * 删除address信息
     * 
     * @param id address主键
     * @return 结果
     */
    public int deleteInfoAddressById(Long id);

    public int deleteById(Long id);
}
